"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-markup");
require("./prism-clike");
require("./prism-java");
require("./prism-javadoclike");
var codeLinePattern = /(^(?:\s*(?:\*\s*)*))[^*\s].*$/m;
var memberReference = /#\s*\w+(?:\s*\([^()]*\))?/.source;
var reference = /(?:[a-zA-Z]\w+\s*\.\s*)*[A-Z]\w*(?:\s*<mem>)?|<mem>/.source.replace(/<mem>/g, function () {
    return memberReference;
});
prism_core_1.default.languages.javadoc = prism_core_1.default.languages.extend('javadoclike', {});
prism_core_1.default.languages.insertBefore('javadoc', 'keyword', {
    reference: {
        pattern: RegExp(/(@(?:exception|throws|see|link|linkplain|value)\s+(?:\*\s*)?)/.source +
            '(?:' +
            reference +
            ')'),
        lookbehind: true,
        inside: {
            function: {
                pattern: /(#\s*)\w+(?=\s*\()/,
                lookbehind: true,
            },
            field: {
                pattern: /(#\s*)\w+/,
                lookbehind: true,
            },
            namespace: {
                pattern: /\b(?:[a-z]\w*\s*\.\s*)+/,
                inside: {
                    punctuation: /\./,
                },
            },
            'class-name': /\b[A-Z]\w*/,
            keyword: prism_core_1.default.languages.java.keyword,
            punctuation: /[#()[\],.]/,
        },
    },
    'class-name': {
        // @param <T> the first generic type parameter
        pattern: /(@param\s+)<[A-Z]\w*>/,
        lookbehind: true,
        inside: {
            punctuation: /[.<>]/,
        },
    },
    'code-section': [
        {
            pattern: /(\{@code\s+(?!\s))(?:[^\s{}]|\s+(?![\s}])|\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\})+(?=\s*\})/,
            lookbehind: true,
            inside: {
                code: {
                    // there can't be any HTML inside of {@code} tags
                    pattern: codeLinePattern,
                    lookbehind: true,
                    inside: prism_core_1.default.languages.java,
                    alias: 'language-java',
                },
            },
        },
        {
            pattern: /(<(code|pre|tt)>(?!<code>)\s*)\S(?:\S|\s+\S)*?(?=\s*<\/\2>)/,
            lookbehind: true,
            inside: {
                line: {
                    pattern: codeLinePattern,
                    lookbehind: true,
                    inside: {
                        // highlight HTML tags and entities
                        tag: prism_core_1.default.languages.markup.tag,
                        entity: prism_core_1.default.languages.markup.entity,
                        code: {
                            // everything else is Java code
                            pattern: /.+/,
                            inside: prism_core_1.default.languages.java,
                            alias: 'language-java',
                        },
                    },
                },
            },
        },
    ],
    tag: prism_core_1.default.languages.markup.tag,
    entity: prism_core_1.default.languages.markup.entity,
});
prism_core_1.default.languages.javadoclike.addSupport('java', prism_core_1.default.languages.javadoc);
