"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-clike");
require("./prism-javascript");
require("./prism-javadoclike");
require("./prism-typescript");
var javascript = prism_core_1.default.languages.javascript;
var type = /{(?:[^{}]|{(?:[^{}]|{[^{}]*})*})+}/.source;
var parameterPrefix = '(@(?:param|arg|argument|property)\\s+(?:' + type + '\\s+)?)';
prism_core_1.default.languages.jsdoc = prism_core_1.default.languages.extend('javadoclike', {
    parameter: {
        // @param {string} foo - foo bar
        pattern: RegExp(parameterPrefix + /(?:(?!\s)[$\w\xA0-\uFFFF.])+(?=\s|$)/.source),
        lookbehind: true,
        inside: {
            punctuation: /\./,
        },
    },
});
prism_core_1.default.languages.insertBefore('jsdoc', 'keyword', {
    'optional-parameter': {
        // @param {string} [baz.foo="bar"] foo bar
        pattern: RegExp(parameterPrefix +
            /\[(?:(?!\s)[$\w\xA0-\uFFFF.])+(?:=[^[\]]+)?\](?=\s|$)/.source),
        lookbehind: true,
        inside: {
            parameter: {
                pattern: /(^\[)[$\w\xA0-\uFFFF\.]+/,
                lookbehind: true,
                inside: {
                    punctuation: /\./,
                },
            },
            code: {
                pattern: /(=)[\s\S]*(?=\]$)/,
                lookbehind: true,
                inside: javascript,
                alias: 'language-javascript',
            },
            punctuation: /[=[\]]/,
        },
    },
    'class-name': [
        {
            pattern: RegExp(/(@(?:augments|extends|class|interface|memberof!?|template|this|typedef)\s+(?:<TYPE>\s+)?)[A-Z]\w*(?:\.[A-Z]\w*)*/.source.replace(/<TYPE>/g, function () {
                return type;
            })),
            lookbehind: true,
            inside: {
                punctuation: /\./,
            },
        },
        {
            pattern: RegExp('(@[a-z]+\\s+)' + type),
            lookbehind: true,
            inside: {
                string: javascript.string,
                number: javascript.number,
                boolean: javascript.boolean,
                keyword: prism_core_1.default.languages.typescript.keyword,
                operator: /=>|\.\.\.|[&|?:*]/,
                punctuation: /[.,;=<>{}()[\]]/,
            },
        },
    ],
    example: {
        pattern: /(@example\s+(?!\s))(?:[^@\s]|\s+(?!\s))+?(?=\s*(?:\*\s*)?(?:@\w|\*\/))/,
        lookbehind: true,
        inside: {
            code: {
                pattern: /^(\s*(?:\*\s*)?)\S.*$/m,
                lookbehind: true,
                inside: javascript,
                alias: 'language-javascript',
            },
        },
    },
});
prism_core_1.default.languages.javadoclike.addSupport('javascript', prism_core_1.default.languages.jsdoc);
