"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prism_core_1 = __importDefault(require("./prism-core"));
require("./prism-clike");
prism_core_1.default.languages.kotlin = prism_core_1.default.languages.extend('clike', {
    keyword: {
        // The lookbehind prevents wrong highlighting of e.g. kotlin.properties.get
        pattern: /(^|[^.])\b(?:abstract|actual|annotation|as|break|by|catch|class|companion|const|constructor|continue|crossinline|data|do|dynamic|else|enum|expect|external|final|finally|for|fun|get|if|import|in|infix|init|inline|inner|interface|internal|is|lateinit|noinline|null|object|open|operator|out|override|package|private|protected|public|reified|return|sealed|set|super|suspend|tailrec|this|throw|to|try|typealias|val|var|vararg|when|where|while)\b/,
        lookbehind: true,
    },
    function: [
        {
            pattern: /(?:`[^\r\n`]+`|\w+)(?=\s*\()/,
            greedy: true,
        },
        {
            pattern: /(\.)(?:`[^\r\n`]+`|\w+)(?=\s*\{)/,
            lookbehind: true,
            greedy: true,
        },
    ],
    number: /\b(?:0[xX][\da-fA-F]+(?:_[\da-fA-F]+)*|0[bB][01]+(?:_[01]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?[fFL]?)\b/,
    operator: /\+[+=]?|-[-=>]?|==?=?|!(?:!|==?)?|[\/*%<>]=?|[?:]:?|\.\.|&&|\|\||\b(?:and|inv|or|shl|shr|ushr|xor)\b/,
});
delete prism_core_1.default.languages.kotlin['class-name'];
prism_core_1.default.languages.insertBefore('kotlin', 'string', {
    'raw-string': {
        pattern: /("""|''')[\s\S]*?\1/,
        alias: 'string',
    },
});
prism_core_1.default.languages.insertBefore('kotlin', 'keyword', {
    annotation: {
        pattern: /\B@(?:\w+:)?(?:[A-Z]\w*|\[[^\]]+\])/,
        alias: 'builtin',
    },
});
prism_core_1.default.languages.insertBefore('kotlin', 'function', {
    label: {
        pattern: /\w+@|@\w+/,
        alias: 'symbol',
    },
});
var interpolation = [
    {
        pattern: /\$\{[^}]+\}/,
        inside: {
            delimiter: {
                pattern: /^\$\{|\}$/,
                alias: 'variable',
            },
            rest: prism_core_1.default.languages.kotlin,
        },
    },
    {
        pattern: /\$\w+/,
        alias: 'variable',
    },
];
prism_core_1.default.languages.kotlin['string'].inside = prism_core_1.default.languages.kotlin['raw-string'].inside = {
    interpolation: interpolation,
};
prism_core_1.default.languages.kt = prism_core_1.default.languages.kotlin;
prism_core_1.default.languages.kts = prism_core_1.default.languages.kotlin;
